@@ -12,18 +12,18 @@ our @EXPORT_TYPES = qw/TERMINFO_BOOLEAN TERMINFO_NUMERIC TERMINFO_STRING/;
 
 our @EXPORT_OK = (@EXPORT_TYPES);
 our %EXPORT_TAGS = ('all'       => \@EXPORT_OK,
-		    'types'     => \@EXPORT_TYPES);
+                    'types'     => \@EXPORT_TYPES);
 
 # ABSTRACT: Terminfo constants
 
-our $VERSION = '0.010'; # VERSION
+our $VERSION = '0.011'; # VERSION
 
 
 1;
 
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
@@ -31,7 +31,7 @@ MarpaX::Database::Terminfo::Constants - Terminfo constants
 
 =head1 VERSION
 
-version 0.010
+version 0.011
 
 =head1 SYNOPSIS
 
@@ -69,10 +69,6 @@ L<GNU Ncurses|http://www.gnu.org/software/ncurses/>
 
 jddurand <jeandamiendurand@free.fr>
 
-=head1 CONTRIBUTOR
-
-Jean-Damien Durand <jeandamiendurand@free.fr>
-
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2013 by Jean-Damien Durand.
