@@ -6,7 +6,7 @@ use MarpaX::Database::Terminfo::Grammar::Actions;
 
 # ABSTRACT: Terminfo grammar in Marpa BNF
 
-our $VERSION = '0.010'; # VERSION
+our $VERSION = '0.011'; # VERSION
 
 
 our $GRAMMAR_CONTENT = do {local $/; <DATA>};
@@ -18,8 +18,8 @@ sub new {
 
     $self->{_content} = $GRAMMAR_CONTENT;
     $self->{_grammar_option} = {
-	action_object  => sprintf('%s::%s', __PACKAGE__, 'Actions'),
-	source => \$self->{_content}
+        action_object  => sprintf('%s::%s', __PACKAGE__, 'Actions'),
+        source => \$self->{_content}
     };
     $self->{_recce_option} = {};
 
@@ -51,7 +51,7 @@ sub recce_option {
 
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
@@ -59,7 +59,7 @@ MarpaX::Database::Terminfo::Grammar - Terminfo grammar in Marpa BNF
 
 =head1 VERSION
 
-version 0.010
+version 0.011
 
 =head1 SYNOPSIS
 
@@ -98,10 +98,6 @@ L<Marpa::R2>
 
 jddurand <jeandamiendurand@free.fr>
 
-=head1 CONTRIBUTOR
-
-Jean-Damien Durand <jeandamiendurand@free.fr>
-
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2013 by Jean-Damien Durand.
