@@ -9,7 +9,7 @@ use Log::Any qw/$log/;
 
 # ABSTRACT: Terminfo grammar actions
 
-our $VERSION = '0.010'; # VERSION
+our $VERSION = '0.011'; # VERSION
 
 
 
@@ -41,7 +41,7 @@ sub _getTerminfo {
     my ($self) = @_;
 
     if (! defined($self->{_terminfo}->[-1])) {
-	$self->{_terminfo}->[-1] = {alias => [], longname => '', feature => []};
+        $self->{_terminfo}->[-1] = {alias => [], longname => '', feature => []};
     }
     return $self->{_terminfo}->[-1];
 }
@@ -52,9 +52,9 @@ sub _pushFeature {
     my $terminfo = $self->_getTerminfo;
 
     foreach (@{$terminfo->{feature}}) {
-	if ($_->{name} eq $name) {
-	    $log->warnf('%s %s: feature %s overwriten', $terminfo->{alias} || [], $terminfo->{longname} || '', $name);
-	}
+        if ($_->{name} eq $name) {
+            $log->warnf('%s %s: feature %s overwriten', $terminfo->{alias} || [], $terminfo->{longname} || '', $name);
+        }
     }
 
     push(@{$terminfo->{feature}}, {type => $type, name => $name, value => $value});
@@ -103,7 +103,7 @@ __END__
 
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
@@ -111,7 +111,7 @@ MarpaX::Database::Terminfo::Grammar::Actions - Terminfo grammar actions
 
 =head1 VERSION
 
-version 0.010
+version 0.011
 
 =head1 DESCRIPTION
 
@@ -153,10 +153,6 @@ Push a new terminfo placeholder.
 
 jddurand <jeandamiendurand@free.fr>
 
-=head1 CONTRIBUTOR
-
-Jean-Damien Durand <jeandamiendurand@free.fr>
-
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2013 by Jean-Damien Durand.
