@@ -5,7 +5,7 @@ package MarpaX::Database::Terminfo::Grammar::CharacterClasses;
 
 # ABSTRACT: Terminfo character classes
 
-our $VERSION = '0.010'; # VERSION
+our $VERSION = '0.011'; # VERSION
 
 
 our $COMMA_HEX  = sprintf('%x', ord(','));
@@ -108,7 +108,7 @@ __END__
 
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
@@ -116,7 +116,7 @@ MarpaX::Database::Terminfo::Grammar::CharacterClasses - Terminfo character class
 
 =head1 VERSION
 
-version 0.010
+version 0.011
 
 =head1 DESCRIPTION
 
@@ -170,10 +170,6 @@ Character class for a isprint or isgraph character
 
 jddurand <jeandamiendurand@free.fr>
 
-=head1 CONTRIBUTOR
-
-Jean-Damien Durand <jeandamiendurand@free.fr>
-
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2013 by Jean-Damien Durand.
