@@ -9,7 +9,7 @@ our @EXPORT_OK = qw/@TOKENSRE %TOKENSRE/;
 
 # ABSTRACT: Terminfo grammar regexps
 
-our $VERSION = '0.010'; # VERSION
+our $VERSION = '0.011'; # VERSION
 
 
 #
@@ -26,7 +26,7 @@ our $ESCAPED       = qr/(?:$CONTROLX|$BACKSLASHX)/;
 our $I_CONSTANT = qr/(?:(0[xX][a-fA-F0-9]+(?:[uU](?:ll|LL|[lL])?|(?:ll|LL|[lL])[uU]?)?)             # Hexadecimal
                       |([1-9][0-9]*(?:[uU](?:ll|LL|[lL])?|(?:ll|LL|[lL])[uU]?)?)                    # Decimal
                       |(0[0-7]*(?:[uU](?:ll|LL|[lL])?|(?:ll|LL|[lL])[uU]?)?)                        # Octal
-                      |([uUL]?'(?:[^'\\\n]|\\(?:[\'\"\?\\abfnrtv]|[0-7]{1..3}|x[a-fA-F0-9]+))+')    # Character
+                      |([uUL]?'(?:[^'\\\n]|\\(?:[\'\"\?\\abfnrtv]|[0-7]{1,3}|x[a-fA-F0-9]+))+')     # Character
                     )/x;
 
 our %TOKENSRE = (
@@ -72,7 +72,7 @@ __END__
 
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
@@ -80,7 +80,7 @@ MarpaX::Database::Terminfo::Grammar::Regexp - Terminfo grammar regexps
 
 =head1 VERSION
 
-version 0.010
+version 0.011
 
 =head1 DESCRIPTION
 
@@ -90,10 +90,6 @@ This modules give the regular expressions associated to terminfo grammar.
 
 jddurand <jeandamiendurand@free.fr>
 
-=head1 CONTRIBUTOR
-
-Jean-Damien Durand <jeandamiendurand@free.fr>
-
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2013 by Jean-Damien Durand.
